# Inizia!

Benvenuto in Rapunzel, un ambiente di sviluppo moderno per Python e R. Ecco alcuni utili scorciatoie da tastiera.


## Lavorare con cartelle e file del progetto

- [`Ctrl+Shift+O`: Apri cartella del progetto](opensesame://event.rapunzel_welcome_open_folders)
- [`Ctrl+O`: Apri file dalle cartelle del progetto](opensesame://event.rapunzel_welcome_open_files)
- [`Ctrl+N`: Crea documento vuoto](opensesame://event.ide_new_file)


## Fare le cose in fretta

- [`Ctrl+Shift+P`: Attiva la tavolozza dei comandi](opensesame://event.command_palette_activate)
- `Ctrl+R`: Salta a funzione o classe


## Esecuzione del codice

- `F5`: Esegui progetto o file
- `F9`: Esegui selezione, cella o riga corrente